@@ -7,12 +7,24 @@
 #define PURIFY_HAS_NOT_USING
 #endif
 
-//! Whether to do logging or not
-#cmakedefine PURIFY_DO_LOGGING
-
 //! Whether to do openmp
 #cmakedefine PURIFY_OPENMP
 
+//! Whether FFTW has openmp
+#cmakedefine PURIFY_OPENMP_FFTW
+
+//! Whether PURIFY is running with mpi
+#cmakedefine PURIFY_MPI
+
+//! Whether PURIFY is running with arrayfire
+#cmakedefine PURIFY_ARRAYFIRE
+
+//! Whether PURIFY is running with CImg
+#cmakedefine PURIFY_CImg
+
+//! Whether PURIFY is running with casacore
+#cmakedefine PURIFY_CASACORE
+
 #include <string>
 #include <tuple>
 
@@ -30,14 +42,6 @@ inline std::tuple<uint8_t, uint8_t, uint8_t> version_tuple() {
 inline std::string gitref() { return "@Purify_GITREF@"; }
 //! Default logging level
 inline std::string default_logging_level() { return "@PURIFY_TEST_LOG_LEVEL@"; }
-//! Default logger name
-inline std::string default_logger_name() { return "@PURIFY_LOGGER_NAME@"; }
-//! Wether to add color to the logger
-inline constexpr bool color_logger() {
-  // clang-format off
-  return @PURIFY_COLOR_LOGGING@;
-  // clang-format on
-}
-}
+} // namespace purify
 
 #endif
